@@ -1,5 +1,5 @@
 #
-# $Id: Storable.pm,v 27.2 2007/01/11 20:20:35 molinam Exp $
+# $Id: Storable.pm,v 28.2 2007/02/08 16:10:01 biersma Exp $
 #
 # (c) 1999-2007 Morgan Stanley Dean Witter and Co.
 # See ..../src/LICENSE for terms of distribution.
@@ -7,7 +7,7 @@
 
 package MQSeries::Message::Storable;
 
-require 5.005;
+use 5.006;
 
 use strict;
 use Carp;
@@ -18,7 +18,7 @@ use MQSeries::Message;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '1.24';
+$VERSION = '1.25';
 @ISA = qw(MQSeries::Message);
 
 #
